import setuptools

setuptools.setup(
    name='phoenixtesting',
    version='0.1.2',
    author='Prateek Joshi',
    author_email='prateekjoshi2013@gmail.com',
    description='Testing Package',
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    )